
#property copyright " 2007 RickD"
#property link      "www.e2e-fx.net"
#property show_inputs

#define major   1
#define minor   0

extern double Lots = 0.1;

extern int BuyStopCnt = 5;
extern int SellStopCnt = 5;

extern int InitialOffset = 20;
extern int OrdersStep = 10;
extern int StopLoss = 10;
extern int TakeProfit = 10;

extern int Slippage = 3;
extern int Magic = 20071030;

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

void init() 
{
}

void deinit() 
{
}

void start() 
{
  SetOrders();
}

void SetOrders() 
{
  double BS_Price, SS_Price;
  double sl, tp;

  int cnt = MathMax(BuyStopCnt, SellStopCnt);
  for (int i=0; i < cnt; i++)
  {
    if (i < BuyStopCnt)
    {
      if (i == 0)
        BS_Price = iOpen(NULL, PERIOD_D1, 0) + InitialOffset*Point;
      else
        BS_Price += OrdersStep*Point;
  
      sl = If(StopLoss > 0, BS_Price - StopLoss*Point, 0);
      tp = If(TakeProfit > 0, BS_Price + TakeProfit*Point, 0);

      SetBuyStop(Symbol(), GetLots(), BS_Price, sl, tp, Magic);
    }
    
    //-----
    
    if (i < SellStopCnt)
    {
      if (i == 0)
        SS_Price = iOpen(NULL, PERIOD_D1, 0) - InitialOffset*Point;
      else
        SS_Price -= OrdersStep*Point;
  
      sl = If(StopLoss > 0, SS_Price + StopLoss*Point, 0);
      tp = If(TakeProfit > 0, SS_Price - TakeProfit*Point, 0);

      SetSellStop(Symbol(), GetLots(), SS_Price, sl, tp, Magic);
    }
  }
}

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

double GetLots() 
{
  return (Lots);
}

double If(bool cond, double if_true, double if_false)
{
  if (cond) return (if_true);
  return (if_false);
}

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#include <stdlib.mqh>
#include <stderror.mqh>

int SleepOk = 1000;
int SleepErr = 4000;

int SetBuyStop(string symbol, double lot, double price, double sl, double tp, int magic, string comment="", datetime exp = 0) 
{
  int dig = MarketInfo(symbol, MODE_DIGITS);

  price = NormalizeDouble(price, dig);
  sl = NormalizeDouble(sl, dig);
  tp = NormalizeDouble(tp, dig);
  
  string _lot = DoubleToStr(lot, 2);
  string _price = DoubleToStr(price, dig);
  string _sl = DoubleToStr(sl, dig);
  string _tp = DoubleToStr(tp, dig);

  Print("SetBuyStop \"", symbol, "\", ", _lot, ", ", _price, ", ", Slippage, ", ", _sl, ", ", _tp, ", ", magic, ", \"", comment, "\"");
  
  int res = OrderSend(symbol, OP_BUYSTOP, lot, price, Slippage, sl, tp, comment, magic, exp);
  if (res >= 0) {
    Sleep(SleepOk);
    return (res);
  } 	
   	
  int code = GetLastError();
  Print("Error setting BUYSTOP order: ", ErrorDescription(code), " (", code, ")");
  Sleep(SleepErr);
	
  return (-1);
}

int SetSellStop(string symbol, double lot, double price, double sl, double tp, int magic, string comment="", datetime exp=0) 
{
  int dig = MarketInfo(symbol, MODE_DIGITS);

  price = NormalizeDouble(price, dig);
  sl = NormalizeDouble(sl, dig);
  tp = NormalizeDouble(tp, dig);
  
  string _lot = DoubleToStr(lot, 2);
  string _price = DoubleToStr(price, dig);
  string _sl = DoubleToStr(sl, dig);
  string _tp = DoubleToStr(tp, dig);

  Print("SetSellStop \"", symbol, "\", ", _lot, ", ", _price, ", ", Slippage, ", ", _sl, ", ", _tp, ", ", magic, ", \"", comment, "\"");
  
  int res = OrderSend(symbol, OP_SELLSTOP, lot, price, Slippage, sl, tp, comment, magic, exp);
  if (res >= 0) {
    Sleep(SleepOk);
    return (res);
  } 	
   	
  int code = GetLastError();
  Print("Error setting SELLSTOP order: ", ErrorDescription(code), " (", code, ")");
  Sleep(SleepErr);
	
  return (-1);
}

